@@ -17,6 +17,7 @@
 
 package org.apache.streampark.console.core.annotation;
 
+import org.apache.streampark.console.core.aspect.PermissionAspect;
 import org.apache.streampark.console.core.task.FlinkAppHttpWatcher;
 
 import org.aspectj.lang.ProceedingJoinPoint;
@@ -30,9 +31,8 @@ import java.lang.annotation.Target;
  * In the controller({@link org.apache.streampark.console.core.controller}), If some method causes
  * application state update, need to add this annotation, This annotation marks which methods will
  * cause the application to be updated, Will work together with {@link
- * org.apache.streampark.console.core.aspect.StreamParkAspect#appUpdated(ProceedingJoinPoint)}, The
- * final purpose will be refresh {@link FlinkAppHttpWatcher#WATCHING_APPS}, Make the state of the
- * job consistent with the database
+ * PermissionAspect#appUpdated(ProceedingJoinPoint)}, The final purpose will be refresh {@link
+ * FlinkAppHttpWatcher#WATCHING_APPS}, Make the state of the job consistent with the database
  */
 @Target(ElementType.METHOD)
 @Retention(RetentionPolicy.RUNTIME)
