@@ -29,7 +29,6 @@ import org.apache.streampark.common.util.Utils;
 import org.apache.streampark.console.base.util.WebUtils;
 import org.apache.streampark.console.core.bean.MavenConfig;
 import org.apache.streampark.console.core.entity.FlinkEnv;
-import org.apache.streampark.console.core.service.SettingService;
 
 import lombok.extern.slf4j.Slf4j;
 import org.springframework.beans.factory.annotation.Autowired;
@@ -60,15 +59,13 @@ public class EnvInitializer implements ApplicationRunner {
 
   @Autowired private ApplicationContext context;
 
-  @Autowired private SettingService settingService;
-
   private final Set<StorageType> initialized = new HashSet<>(2);
 
   private final FileFilter fileFilter = p -> !".gitkeep".equals(p.getName());
 
   private static final Pattern PATTERN_FLINK_SHIMS_JAR =
       Pattern.compile(
-          "^streampark-flink-shims_flink-(1.1[2-9])_(2.11|2.12)-(.*).jar$",
+          "^streampark-flink-shims_flink-(1.1[2-9]|1.20)_(2.11|2.12)-(.*).jar$",
           Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
 
   @Override
@@ -100,6 +97,7 @@ public class EnvInitializer implements ApplicationRunner {
   }
 
   private void initInternalConfig(Environment springEnv) {
+    InternalConfigHolder.initConfigHub();
     // override config from spring application.yaml
     InternalConfigHolder.keys().stream()
         .filter(springEnv::containsProperty)
