@@ -256,7 +256,7 @@ public class AppBuildPipeServiceImpl
                       app.getJobName().concat(" release failed"),
                       Utils.stringifyException(snapshot.error().exception()),
                       NoticeType.EXCEPTION);
-              messageService.push(message);
+              messageService.save(message);
               app.setRelease(ReleaseState.FAILED.get());
               app.setOptionState(OptionState.NONE.getValue());
               app.setBuild(true);
@@ -356,7 +356,7 @@ public class AppBuildPipeServiceImpl
         log.info("Submit params to building pipeline : {}", k8sSessionBuildRequest);
         return FlinkK8sSessionBuildPipeline.of(k8sSessionBuildRequest);
       case KUBERNETES_NATIVE_APPLICATION:
-        DockerConfig dockerConfig = DockerConfig.fromSetting();
+        DockerConfig dockerConfig = settingService.getDockerConfig();
         FlinkK8sApplicationBuildRequest k8sApplicationBuildRequest =
             new FlinkK8sApplicationBuildRequest(
                 app.getJobName(),
@@ -418,6 +418,7 @@ public class AppBuildPipeServiceImpl
       } else if (resourceFrom == ResourceFrom.UPLOAD) {
         userJar = new File(WebUtils.getAppTempDir(), app.getJar());
       } else {
+        log.error("ResourceFrom error:{}.", resourceFrom);
         throw new IllegalArgumentException("ResourceFrom error: " + resourceFrom);
       }
       // 2) copy user jar to localUpload DIR
