@@ -34,6 +34,7 @@ import org.apache.streampark.common.util.ThreadUtils;
 import org.apache.streampark.common.util.Utils;
 import org.apache.streampark.common.util.YarnUtils;
 import org.apache.streampark.console.base.domain.RestRequest;
+import org.apache.streampark.console.base.domain.RestResponse;
 import org.apache.streampark.console.base.exception.ApiAlertException;
 import org.apache.streampark.console.base.exception.ApiDetailException;
 import org.apache.streampark.console.base.exception.ApplicationException;
@@ -51,7 +52,7 @@ import org.apache.streampark.console.core.entity.FlinkCluster;
 import org.apache.streampark.console.core.entity.FlinkEnv;
 import org.apache.streampark.console.core.entity.FlinkSql;
 import org.apache.streampark.console.core.entity.Project;
-import org.apache.streampark.console.core.entity.SavePoint;
+import org.apache.streampark.console.core.entity.Savepoint;
 import org.apache.streampark.console.core.enums.AppExistsState;
 import org.apache.streampark.console.core.enums.CandidateType;
 import org.apache.streampark.console.core.enums.ChangedType;
@@ -74,13 +75,15 @@ import org.apache.streampark.console.core.service.FlinkClusterService;
 import org.apache.streampark.console.core.service.FlinkEnvService;
 import org.apache.streampark.console.core.service.FlinkSqlService;
 import org.apache.streampark.console.core.service.ProjectService;
-import org.apache.streampark.console.core.service.SavePointService;
+import org.apache.streampark.console.core.service.SavepointService;
 import org.apache.streampark.console.core.service.ServiceHelper;
 import org.apache.streampark.console.core.service.SettingService;
 import org.apache.streampark.console.core.service.VariableService;
 import org.apache.streampark.console.core.service.YarnQueueService;
+import org.apache.streampark.console.core.task.CheckpointProcessor;
 import org.apache.streampark.console.core.task.FlinkAppHttpWatcher;
 import org.apache.streampark.console.core.task.FlinkK8sWatcherWrapper;
+import org.apache.streampark.console.system.service.MemberService;
 import org.apache.streampark.flink.client.FlinkClient;
 import org.apache.streampark.flink.client.bean.CancelRequest;
 import org.apache.streampark.flink.client.bean.CancelResponse;
@@ -192,7 +195,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
 
   @Autowired private FlinkSqlService flinkSqlService;
 
-  @Autowired private SavePointService savePointService;
+  @Autowired private SavepointService savepointService;
 
   @Autowired private EffectiveService effectiveService;
 
@@ -214,6 +217,10 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
 
   @Autowired private FlinkK8sWatcherWrapper k8sWatcherWrapper;
 
+  @Autowired private CheckpointProcessor checkpointProcessor;
+
+  @Autowired private MemberService memberService;
+
   private static final int CPU_NUM = Math.max(2, Runtime.getRuntime().availableProcessors() * 4);
 
   private final ExecutorService bootstrapExecutor =
@@ -332,6 +339,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     try {
       file.transferTo(saveFile);
     } catch (Exception e) {
+      log.error("Upload file {} failed!", fileName, e);
       throw new ApiDetailException(e);
     }
     return saveFile.getAbsolutePath();
@@ -404,7 +412,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     backUpService.removeApp(application);
 
     // 6) remove savepoint
-    savePointService.removeApp(application);
+    savepointService.removeApp(application);
 
     // 7) remove BuildPipeline
     appBuildPipeService.removeApp(application.getId());
@@ -495,7 +503,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
         HdfsOperator.delete(path);
       }
     } catch (Exception e) {
-      // skip
+      log.error("Remove application {} failed!", appId, e);
     }
   }
 
@@ -550,16 +558,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
           }
 
           // 4) appControl
-          AppControl appControl =
-              new AppControl()
-                  .setAllowBuild(
-                      record.getBuildStatus() == null
-                          || !PipelineStatus.running.getCode().equals(record.getBuildStatus()))
-                  .setAllowStart(
-                      !record.shouldBeTrack()
-                          && PipelineStatus.success.getCode().equals(record.getBuildStatus()))
-                  .setAllowStop(record.isRunning());
-          record.setAppControl(appControl);
+          record.setAppControl(buildAppControl(record));
         });
 
     return page;
@@ -678,6 +677,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
           .toCompletableFuture()
           .get(5, TimeUnit.SECONDS);
     } else {
+      log.error("Job executionMode must be kubernetes-session|kubernetes-application.");
       throw new ApiAlertException(
           "Job executionMode must be kubernetes-session|kubernetes-application.");
     }
@@ -805,6 +805,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
       }
       return true;
     } else {
+      log.error("Create application failed!");
       throw new ApiAlertException("create application failed");
     }
   }
@@ -992,7 +993,6 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     application.setDynamicProperties(appParam.getDynamicProperties());
     application.setResolveOrder(appParam.getResolveOrder());
     application.setExecutionMode(appParam.getExecutionMode());
-    application.setFlinkClusterId(appParam.getFlinkClusterId());
     application.setFlinkImage(appParam.getFlinkImage());
     application.updateHotParams(appParam);
     application.setK8sRestExposedType(appParam.getK8sRestExposedType());
@@ -1186,7 +1186,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
   }
 
   @Override
-  public void forcedStop(Application app) {
+  public void abort(Application app) {
     CompletableFuture<SubmitResponse> startFuture = startFutureMap.remove(app.getId());
     CompletableFuture<CancelResponse> cancelFuture = cancelFutureMap.remove(app.getId());
     Application application = this.baseMapper.getApp(app);
@@ -1201,7 +1201,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
       cancelFuture.cancel(true);
     }
     if (startFuture == null && cancelFuture == null) {
-      this.doStopped(app);
+      this.doAbort(app);
     }
   }
 
@@ -1254,9 +1254,21 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
       }
     }
     application.setByHotParams();
+    application.setAppControl(buildAppControl(application));
     return application;
   }
 
+  private AppControl buildAppControl(Application app) {
+    return new AppControl()
+        .setAllowBuild(
+            app.getBuildStatus() == null
+                || !PipelineStatus.running.getCode().equals(app.getBuildStatus()))
+        .setAllowStart(
+            !app.shouldBeTrack() && PipelineStatus.success.getCode().equals(app.getBuildStatus()))
+        .setAllowStop(app.isRunning())
+        .setAllowView(app.shouldBeTrack());
+  }
+
   @Override
   public String getMain(Application application) {
     File jarFile;
@@ -1296,11 +1308,12 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     applicationLog.setAppId(application.getId());
     applicationLog.setJobManagerUrl(application.getJobManagerUrl());
     applicationLog.setOptionTime(new Date());
+
     if (ExecutionMode.isYarnMode(application.getExecutionMode())) {
       applicationLog.setYarnAppId(application.getClusterId());
     }
 
-    if (appParam.getSavePointed()) {
+    if (appParam.getRestoreOrTriggerSavepoint()) {
       if (!application.isKubernetesModeJob()) {
         FlinkAppHttpWatcher.addSavepoint(application.getId());
         application.setOptionState(OptionState.SAVEPOINTING.getValue());
@@ -1321,10 +1334,23 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
 
     // infer savepoint
     String customSavepoint = null;
-    if (appParam.getSavePointed()) {
-      customSavepoint = appParam.getSavePoint();
+    if (appParam.getRestoreOrTriggerSavepoint()) {
+      customSavepoint = appParam.getSavepointPath();
       if (StringUtils.isBlank(customSavepoint)) {
-        customSavepoint = savePointService.getSavePointPath(appParam);
+        customSavepoint = savepointService.getSavePointPath(appParam);
+      }
+      if (StringUtils.isBlank(customSavepoint)
+          || application.getExecutionModeEnum() == ExecutionMode.YARN_APPLICATION) {
+        customSavepoint = Workspace.remote().APP_SAVEPOINTS();
+      }
+      if (StringUtils.isNotBlank(customSavepoint)) {
+        savepointService.processPath(
+            customSavepoint, application.getJobName(), application.getId());
+      } else {
+        throw new IllegalArgumentException(
+            String.format(
+                "[StreamPark] executionMode: %s, savePoint path is null or invalid.",
+                application.getExecutionModeEnum().getName()));
       }
     }
 
@@ -1354,8 +1380,8 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
             properties,
             clusterId,
             application.getJobId(),
-            appParam.getSavePointed(),
-            appParam.getDrain() == null ? false : appParam.getDrain(),
+            appParam.getRestoreOrTriggerSavepoint(),
+            appParam.getDrain() != null && appParam.getDrain(),
             customSavepoint,
             namespace);
 
@@ -1368,7 +1394,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     TrackId trackId =
         application.isKubernetesModeJob() ? k8sWatcherWrapper.toTrackId(application) : null;
 
-    cancelFuture.whenComplete(
+    cancelFuture.whenCompleteAsync(
         (cancelResponse, throwable) -> {
           cancelFutureMap.remove(application.getId());
 
@@ -1379,19 +1405,23 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
             applicationLogService.save(applicationLog);
 
             if (throwable instanceof CancellationException) {
-              doStopped(application);
+              doAbort(application);
             } else {
-              log.error("stop flink job failed.", throwable);
+              log.error("abort flink job failed.", throwable);
               application.setOptionState(OptionState.NONE.getValue());
               application.setState(FlinkAppState.FAILED.getValue());
               updateById(application);
 
-              if (appParam.getSavePointed()) {
-                savePointService.expire(application.getId());
+              if (appParam.getRestoreOrTriggerSavepoint()) {
+                savepointService.expire(application.getId());
               }
-              // re-tracking flink job on kubernetes and logging exception
               if (application.isKubernetesModeJob()) {
-                flinkK8sWatcher.unWatching(trackId);
+                try {
+                  KubernetesDeploymentHelper.delete(
+                      application.getK8sNamespace(), application.getJobName());
+                } catch (Exception e) {
+                  log.error("job abort failed!", e);
+                }
               } else {
                 FlinkAppHttpWatcher.unWatching(application.getId());
               }
@@ -1403,17 +1433,17 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
           // save log...
           applicationLogService.save(applicationLog);
 
-          if (cancelResponse != null && cancelResponse.savePointDir() != null) {
-            String savePointDir = cancelResponse.savePointDir();
-            log.info("savePoint path: {}", savePointDir);
-            SavePoint savePoint = new SavePoint();
-            savePoint.setPath(savePointDir);
-            savePoint.setAppId(application.getId());
-            savePoint.setLatest(true);
-            savePoint.setType(CheckPointType.SAVEPOINT.get());
-            savePoint.setCreateTime(new Date());
-            savePoint.setTriggerTime(triggerTime);
-            savePointService.save(savePoint);
+          if (cancelResponse != null && cancelResponse.savepointDir() != null) {
+            String savepointDir = cancelResponse.savepointDir();
+            log.info("savepoint path: {}", savepointDir);
+            Savepoint savepoint = new Savepoint();
+            savepoint.setPath(savepointDir);
+            savepoint.setAppId(application.getId());
+            savepoint.setLatest(true);
+            savepoint.setType(CheckPointType.SAVEPOINT.get());
+            savepoint.setCreateTime(new Date());
+            savepoint.setTriggerTime(triggerTime);
+            savepointService.saveSavePoint(savepoint);
           }
 
           if (application.isKubernetesModeJob()) {
@@ -1424,9 +1454,9 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
 
   @Override
   public String checkSavepointPath(Application appParam) throws Exception {
-    String savepointPath = appParam.getSavePoint();
+    String savepointPath = appParam.getSavepointPath();
     if (StringUtils.isBlank(savepointPath)) {
-      savepointPath = savePointService.getSavePointPath(appParam);
+      savepointPath = savepointService.getSavePointPath(appParam);
     }
 
     if (StringUtils.isNotBlank(savepointPath)) {
@@ -1434,29 +1464,29 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
       final String scheme = uri.getScheme();
       final String pathPart = uri.getPath();
       if (scheme == null) {
-        return "This state.savepoints.dir value "
+        return "This state savepoint dir value "
             + savepointPath
             + " scheme (hdfs://, file://, etc) of  is null. Please specify the file system scheme explicitly in the URI.";
       }
       if (pathPart == null) {
-        return "This state.savepoints.dir value "
+        return "This state savepoint dir value "
             + savepointPath
             + " path part to store the checkpoint data in is null. Please specify a directory path for the checkpoint data.";
       }
       if (pathPart.isEmpty() || "/".equals(pathPart)) {
-        return "This state.savepoints.dir value "
+        return "This state savepoint dir value "
             + savepointPath
             + " Cannot use the root directory for checkpoints.";
       }
       return null;
     } else {
-      return "When custom savepoint is not set, state.savepoints.dir needs to be set in properties or flink-conf.yaml of application";
+      return "When a custom savepoint is not set, state.savepoints.dir or execution.checkpointing.savepoint-dir needs to be configured in the properties or flink-conf.yaml of the application.";
     }
   }
 
   @Override
   public void persistMetrics(Application appParam) {
-    if (appParam.getFlinkAppStateEnum() == FlinkAppState.RUNNING) {
+    if (appParam.getState() != null && appParam.getFlinkAppStateEnum() == FlinkAppState.RUNNING) {
       appParam.setEndTime(null);
       appParam.setDuration(null);
     }
@@ -1504,14 +1534,14 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
       if (!application.isNeedRestartOnFailed()) {
         return;
       }
-      appParam.setSavePointed(true);
+      appParam.setRestoreOrTriggerSavepoint(true);
       application.setRestartCount(application.getRestartCount() + 1);
     }
 
     starting(application);
 
     application.setAllowNonRestored(
-        appParam.getAllowNonRestored() == null ? false : appParam.getAllowNonRestored());
+        appParam.getAllowNonRestored() != null && appParam.getAllowNonRestored());
 
     String appConf;
     String flinkUserJar = null;
@@ -1602,7 +1632,6 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     }
 
     AppBuildPipeline buildPipeline = appBuildPipeService.getById(application.getId());
-
     Utils.notNull(buildPipeline);
 
     BuildResult buildResult = buildPipeline.getBuildResult();
@@ -1611,8 +1640,9 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     }
 
     // Get the args after placeholder replacement
-    String applicationArgs =
-        variableService.replaceVariable(application.getTeamId(), application.getArgs());
+    String args =
+        StringUtils.isBlank(appParam.getArgs()) ? application.getArgs() : appParam.getArgs();
+    String applicationArgs = variableService.replaceVariable(application.getTeamId(), args);
 
     String k8sNamespace;
     String k8sClusterId;
@@ -1643,7 +1673,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
             application.getJobName(),
             appConf,
             application.getApplicationType(),
-            getSavePointed(appParam),
+            getSavepointPath(appParam, application.getJobName(), application.getId()),
             applicationArgs,
             buildResult,
             extraParameter,
@@ -1656,7 +1686,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
 
     startFutureMap.put(application.getId(), future);
 
-    future.whenComplete(
+    future.whenCompleteAsync(
         (response, throwable) -> {
           // 1) remove Future
           startFutureMap.remove(application.getId());
@@ -1669,7 +1699,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
             applicationLog.setSuccess(false);
             applicationLogService.save(applicationLog);
             if (throwable instanceof CancellationException) {
-              doStopped(application);
+              doAbort(application);
             } else {
               Application app = getById(appParam.getId());
               app.setState(FlinkAppState.FAILED.getValue());
@@ -1687,6 +1717,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
 
           // 3) success
           applicationLog.setSuccess(true);
+
           if (response.flinkConfig() != null) {
             String jmMemory = response.flinkConfig().get(ConfigConst.KEY_FLINK_JM_PROCESS_MEMORY());
             if (jmMemory != null) {
@@ -1788,7 +1819,9 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
 
     if (ExecutionMode.isKubernetesApplicationMode(application.getExecutionMode())) {
       String archiveDir =
-          flinkEnv.getFlinkConfig().getProperty(JobManagerOptions.ARCHIVE_DIR.key());
+          flinkEnvService
+              .getFlinkConfig(flinkEnv, application)
+              .getProperty(JobManagerOptions.ARCHIVE_DIR.key());
       if (archiveDir != null) {
         properties.put(JobManagerOptions.ARCHIVE_DIR.key(), archiveDir);
       }
@@ -1820,20 +1853,23 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     return properties;
   }
 
-  private void doStopped(Application appParam) {
+  private void doAbort(Application appParam) {
     Application application = getById(appParam);
     application.setOptionState(OptionState.NONE.getValue());
     application.setState(FlinkAppState.CANCELED.getValue());
     application.setOptionTime(new Date());
     updateById(application);
-    savePointService.expire(application.getId());
-    // re-tracking flink job on kubernetes and logging exception
+    savepointService.expire(application.getId());
     if (application.isKubernetesModeJob()) {
-      TrackId id = k8sWatcherWrapper.toTrackId(application);
-      flinkK8sWatcher.doWatching(id);
+      try {
+        KubernetesDeploymentHelper.delete(application.getK8sNamespace(), application.getJobName());
+      } catch (Exception e) {
+        log.error("job abort failed!", e);
+      }
     } else {
       FlinkAppHttpWatcher.unWatching(application.getId());
     }
+
     // kill application
     if (ExecutionMode.isYarnMode(application.getExecutionModeEnum())) {
       try {
@@ -1842,7 +1878,8 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
           YarnClient yarnClient = HadoopUtils.yarnClient();
           yarnClient.killApplication(applications.get(0).getApplicationId());
         }
-      } catch (Exception ignored) {
+      } catch (Exception e) {
+        log.error("job abort failed!", e);
       }
     }
   }
@@ -1855,18 +1892,20 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     return false;
   }
 
-  private String getSavePointed(Application appParam) {
-    if (appParam.getSavePointed() != null && appParam.getSavePointed()) {
-      if (StringUtils.isBlank(appParam.getSavePoint())) {
-        SavePoint savePoint = savePointService.getLatest(appParam.getId());
-        if (savePoint != null) {
-          return savePoint.getPath();
+  private String getSavepointPath(Application appParam, String jobName, Long jobId) {
+    String path = null;
+    if (appParam.getRestoreOrTriggerSavepoint() != null
+        && appParam.getRestoreOrTriggerSavepoint()) {
+      if (StringUtils.isBlank(appParam.getSavepointPath())) {
+        Savepoint savepoint = savepointService.getLatest(appParam.getId());
+        if (savepoint != null) {
+          path = savepoint.getPath();
         }
       } else {
-        return appParam.getSavePoint();
+        path = appParam.getSavepointPath();
       }
     }
-    return null;
+    return savepointService.processPath(path, jobName, jobId);
   }
 
   /**
@@ -1944,6 +1983,60 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     }
   }
 
+  @Override
+  public RestResponse buildApplication(Long appId, boolean forceBuild) throws Exception {
+    Application app = this.getById(appId);
+
+    ApiAlertException.throwIfNull(
+        app.getVersionId(), "Please bind a Flink version to the current flink job.");
+    // 1) check flink version
+    FlinkEnv env = flinkEnvService.getById(app.getVersionId());
+    boolean checkVersion = env.getFlinkVersion().checkVersion(false);
+    if (!checkVersion) {
+      throw new ApiAlertException("Unsupported flink version: " + env.getFlinkVersion().version());
+    }
+
+    // 2) check env
+    boolean envOk = this.checkEnv(app);
+    if (!envOk) {
+      throw new ApiAlertException(
+          "Check flink env failed, please check the flink version of this job");
+    }
+
+    if (!forceBuild && !appBuildPipeService.allowToBuildNow(appId)) {
+      throw new ApiAlertException(
+          "The job is invalid, or the job cannot be built while it is running");
+    }
+    // check if you need to go through the build process (if the jar and pom have changed,
+    // you need to go through the build process, if other common parameters are modified,
+    // you don't need to go through the build process)
+
+    ApplicationLog applicationLog = new ApplicationLog();
+    applicationLog.setOptionName(
+        org.apache.streampark.console.core.enums.Operation.RELEASE.getValue());
+    applicationLog.setAppId(app.getId());
+    applicationLog.setOptionTime(new Date());
+
+    boolean needBuild = this.checkBuildAndUpdate(app);
+    if (!needBuild) {
+      applicationLog.setSuccess(true);
+      applicationLogService.save(applicationLog);
+      return RestResponse.success(true);
+    }
+
+    // rollback
+    if (app.isNeedRollback() && app.isFlinkSqlJob()) {
+      flinkSqlService.rollback(app);
+    }
+    boolean actionResult = appBuildPipeService.buildApplication(app, applicationLog);
+    return RestResponse.success(actionResult);
+  }
+
+  @Override
+  public void updateJobManagerUrl(Long id, String url) {
+    baseMapper.updateJobManagerUrl(id, url);
+  }
+
   private Tuple2<String, String> getNamespaceClusterId(Application application) {
     String clusterId = null;
     String k8sNamespace = null;
