@@ -43,20 +43,12 @@ public class ShiroConfig {
 
     LinkedHashMap<String, String> filterChainDefinitionMap = new LinkedHashMap<>();
     filterChainDefinitionMap.put("/actuator/**", "anon");
-
-    filterChainDefinitionMap.put("/doc.html", "anon");
-    filterChainDefinitionMap.put("/swagger-ui.html", "anon");
-    filterChainDefinitionMap.put("/swagger-ui/**", "anon");
-    filterChainDefinitionMap.put("/swagger-resources/**", "anon");
-    filterChainDefinitionMap.put("/v3/api-docs/**", "anon");
-    filterChainDefinitionMap.put("/webjars/**", "anon");
+    filterChainDefinitionMap.put("/h2-console/**", "anon");
 
     filterChainDefinitionMap.put("/passport/**", "anon");
     filterChainDefinitionMap.put("/systemName", "anon");
     filterChainDefinitionMap.put("/member/teams", "anon");
     filterChainDefinitionMap.put("/user/check/**", "anon");
-    filterChainDefinitionMap.put("/user/initTeam", "anon");
-    filterChainDefinitionMap.put("/websocket/**", "anon");
     filterChainDefinitionMap.put("/metrics/**", "anon");
 
     filterChainDefinitionMap.put("/index.html", "anon");
@@ -73,6 +65,7 @@ public class ShiroConfig {
     filterChainDefinitionMap.put("/*.less", "anon");
     filterChainDefinitionMap.put("/*.ico", "anon");
     filterChainDefinitionMap.put("/", "anon");
+    filterChainDefinitionMap.put("/proxy/**", "anon");
     filterChainDefinitionMap.put("/**", "jwt");
 
     shiroFilterFactoryBean.setFilterChainDefinitionMap(filterChainDefinitionMap);
