@@ -26,7 +26,6 @@ enum APP_API {
   COPY = '/flink/app/copy',
   UPLOAD = '/flink/app/upload',
   K8S_START_LOG = '/flink/app/k8sStartLog',
-  DEPLOY = '/flink/app/deploy',
   MAPPING = '/flink/app/mapping',
   YARN = '/flink/app/yarn',
   LIST = '/flink/app/list',
@@ -36,7 +35,7 @@ enum APP_API {
   NAME = '/flink/app/name',
   CHECK_NAME = '/flink/app/checkName',
   CANCEL = '/flink/app/cancel',
-  FORCED_STOP = '/flink/app/forcedStop',
+  ABORT = '/flink/app/abort',
   DELETE = '/flink/app/delete',
   DELETE_BAK = '/flink/app/deletebak',
   CREATE = '/flink/app/create',
@@ -47,8 +46,6 @@ enum APP_API {
   REVOKE = '/flink/app/revoke',
   OPTION_LOG = '/flink/app/optionlog',
   DELETE_OPERATION_LOG = '/flink/app/deleteOperationLog',
-  CHECK_JAR = '/flink/app/checkjar',
-  VERIFY_SCHEMA = '/flink/app/verifySchema',
   CHECK_SAVEPOINT_PATH = '/flink/app/checkSavepointPath',
 }
 
@@ -170,8 +167,8 @@ export function fetchDeleteOperationLog(id: string) {
  * @param params id:string
  * @returns
  */
-export function fetchForcedStop(data: { id: string }): Promise<boolean> {
-  return defHttp.post({ url: APP_API.FORCED_STOP, data });
+export function fetchAbort(data: { id: string }): Promise<boolean> {
+  return defHttp.post({ url: APP_API.ABORT, data });
 }
 
 export function fetchCheckStart(data): Promise<AxiosResponse<number>> {
@@ -212,7 +209,7 @@ export function fetchK8sStartLog(data): Promise<AxiosResponse<any>> {
  */
 export function fetchCheckSavepointPath(data: {
   id?: string;
-  savePoint?: string;
+  savepointPath?: string;
 }): Promise<AxiosResponse<Result>> {
   return defHttp.post(
     { url: APP_API.CHECK_SAVEPOINT_PATH, data },
