@@ -19,7 +19,7 @@ export default {
   id: 'ID',
   appName: 'Job Name',
   searchName: 'Job Name',
-  tags: 'Tags',
+  tags: 'Job Tags',
   owner: 'Owner',
   flinkVersion: 'Flink Version',
   duration: 'Duration',
@@ -27,12 +27,11 @@ export default {
   runStatus: 'Status',
   releaseBuild: 'Release',
   jobType: 'Job Type',
-  developmentMode: 'Development Mode',
-  executionMode: 'Execution Mode',
+  executionMode: 'Deploy Mode',
   historyVersion: 'History Version',
   dependency: 'Dependency',
-  appConf: 'Application Conf',
-  resolveOrder: 'resolveOrder',
+  appConf: 'Configures',
+  resolveOrder: 'Resolve Order',
   parallelism: 'Parallelism',
   restartSize: 'Fault Restart Size',
   faultAlertTemplate: 'Fault Alert Template',
@@ -117,13 +116,16 @@ export default {
     compare: 'Compare',
     compareSelectTips: 'Please select the target version',
     resetApi: 'Rest Api',
+    copyCurl: 'Copy Curl',
+    apiTitle: 'Api Detail',
     resetApiToolTip:
       'Rest API external call interface,other third-party systems easy to access StreamPark',
-    copyStartcURL: 'Copy Start cURL',
-    copyCancelcURL: 'Copy Cancel cURL',
+    copyStartcURL: 'App Start',
+    copyCancelcURL: 'App Cancel',
     apiDocCenter: 'Api Doc Center',
-    nullAccessToken: 'access token is null,please contact the administrator to add.',
-    invalidAccessToken: 'access token is invalid,please contact the administrator.',
+    nullAccessToken: 'The current user have no token, please contact the admin to add',
+    invalidAccessToken: 'access token is invalid, please contact the admin',
+    invalidTokenUser: 'the user is locked, please contact the admin',
     detailTab: {
       detailTabName: {
         option: 'Option',
@@ -167,7 +169,7 @@ export default {
     start: 'Start Job',
     stop: 'Stop Job',
     savepoint: 'Trigger Savepoint',
-    fromSavepoint: 'From savepoint',
+    fromSavepoint: 'Start job from savepoint',
     savepointTip: 'Restore the job from savepoint or latest checkpoint',
     savepointInput: 'Specify the savepoint/checkpoint path',
     savepointSwitch:
@@ -212,7 +214,7 @@ export default {
     savepoint: 'Trigger Savepoint',
     detail: 'View Detail',
     startLog: 'See Flink Start log',
-    force: 'Forced Stop Job',
+    force: 'Abort Job',
     copy: 'Copy Job',
     remapping: 'Remapping Job',
     deleteTip: 'Are you sure delete this job ?',
@@ -249,10 +251,10 @@ export default {
     terminated: 'TERMINATED',
   },
   addAppTips: {
-    developmentModePlaceholder: 'please select job type',
-    developmentModeIsRequiredMessage: 'Job Type is required',
-    executionModePlaceholder: 'please select execution mode',
-    executionModeIsRequiredMessage: 'Execution Mode is required',
+    jobTypePlaceholder: 'please select job type',
+    jobTypeIsRequiredMessage: 'Job Type is required',
+    executionModePlaceholder: 'please select deploy mode',
+    executionModeIsRequiredMessage: 'deploy Mode is required',
     hadoopEnvInitMessage:
       'Hadoop environment initialization failed, please check the environment settings',
     resourceFromMessage: 'resource from is required',
