@@ -21,14 +21,16 @@ export default {
   start: 'Start Cluster',
   edit: 'Edit Cluster',
   delete: 'Are you sure delete this cluster ?',
+  searchByName: 'Search by cluster name',
   form: {
     clusterName: 'Cluster Name',
     address: 'Cluster URL',
     internal: 'internal cluster',
-    executionMode: 'Execution Mode',
+    executionMode: 'Deploy Mode',
     versionId: 'Flink Version',
     addExisting: 'existing cluster',
     addNew: 'new cluster',
+    clusterState: 'Cluster State',
     yarnQueue: 'Yarn Queue',
     yarnSessionClusterId: 'Yarn Session Cluster',
     k8sNamespace: 'Kubernetes Namespace',
@@ -65,7 +67,7 @@ export default {
   },
   required: {
     address: 'cluster address is required',
-    executionMode: 'Execution Mode is required',
+    executionMode: 'Deploy Mode is required',
     clusterId: 'Yarn Session Cluster is required',
     versionId: 'Flink Version is required',
     flinkImage: 'Flink Base Docker Image is required',
