@@ -32,6 +32,8 @@ import org.apache.flink.kubernetes.configuration.KubernetesConfigOptions.Service
 
 import javax.annotation.Nonnull
 
+import java.util.{HashMap => JavaHashMap, Map => JavaMap}
+
 import scala.language.postfixOps
 
 /** kubernetes native mode submit */
@@ -70,6 +72,10 @@ trait KubernetesNativeClientTrait extends FlinkClientTrait {
       flinkConfig.removeConfig(KubernetesConfigOptions.NAMESPACE)
     }
 
+    // add pod labels, mainly to facilitate the management of k8s resources
+    addPodLabels(flinkConfig, KubernetesConfigOptions.JOB_MANAGER_LABELS, submitRequest)
+    addPodLabels(flinkConfig, KubernetesConfigOptions.TASK_MANAGER_LABELS, submitRequest)
+
     logInfo(s"""
                |------------------------------------------------------------------
                |Effective submit configuration: $flinkConfig
@@ -87,9 +93,6 @@ trait KubernetesNativeClientTrait extends FlinkClientTrait {
       flinkConfig,
       (jobId, client) => {
         val resp = super.cancelJob(cancelRequest, jobId, client)
-        if (cancelRequest.executionMode == ExecutionMode.KUBERNETES_NATIVE_APPLICATION) {
-          client.shutDownCluster()
-        }
         CancelResponse(resp)
       }
     )
@@ -178,9 +181,22 @@ trait KubernetesNativeClientTrait extends FlinkClientTrait {
     }
 
   def getDefaultKubernetesConf(k8sConf: String): String = {
-    val homePath: String = System.getProperty("user.home")
-    if (k8sConf != null) k8sConf.replace("~", homePath)
-    else homePath.concat("/.kube/config")
+    if (k8sConf != null) {
+      val homePath: String = System.getProperty("user.home")
+      return k8sConf.replace("~", homePath)
+    }
+    null
+  }
+
+  private def addPodLabels(
+      flinkConfig: Configuration,
+      opt: ConfigOption[JavaMap[String, String]],
+      submitRequest: SubmitRequest): Unit = {
+    val labels = flinkConfig
+      .getOptional[JavaMap[String, String]](opt)
+      .orElse(new JavaHashMap[String, String]())
+    labels.put("jobId", submitRequest.jobId)
+    flinkConfig.safeSet(opt, labels)
   }
 
 }
