@@ -305,38 +305,28 @@ class FlinkJobStatusWatcher(conf: JobStatusWatcherConfig = JobStatusWatcherConfi
    */
   private def inferStateFromK8sEvent(@Nonnull trackId: TrackId)(implicit
       pollEmitTime: Long): Option[JobStatusCV] = {
-
     // infer from k8s deployment and event
     val latest: JobStatusCV = watchController.jobStatuses.get(trackId)
+    // whether deployment exists on kubernetes cluster
+    val deployExists = KubernetesRetriever.isDeploymentExists(
+      trackId.namespace,
+      trackId.clusterId
+    )
     val jobState = trackId match {
       case id if watchController.canceling.has(id) =>
         logger.info(s"trackId ${trackId.toString} is canceling")
-        watchController.trackIds.invalidate(id)
-        FlinkJobState.CANCELED
+        if (deployExists) FlinkJobState.CANCELLING else FlinkJobState.CANCELED
       case _ =>
-        // whether deployment exists on kubernetes cluster
-        val deployExists = KubernetesRetriever.isDeploymentExists(
-          trackId.namespace,
-          trackId.clusterId
-        )
-
         val isConnection = KubernetesDeploymentHelper.checkConnection()
 
         if (deployExists) {
-          val deployError = KubernetesDeploymentHelper.isDeploymentError(
-            trackId.namespace,
-            trackId.clusterId
-          )
-          if (!deployError) {
-            logger.info("Task Enter the initialization process.")
-            FlinkJobState.K8S_INITIALIZING
-          } else if (isConnection) {
-            logger.info("Enter the task failure deletion process.")
-            KubernetesDeploymentHelper.watchPodTerminatedLog(
+          if (isConnection) {
+            logger.info("Enter the task starting process.")
+            KubernetesDeploymentHelper.watchDeploymentLog(
               trackId.namespace,
               trackId.clusterId,
               trackId.jobId)
-            FlinkJobState.FAILED
+            FlinkJobState.STARTING
           } else {
             inferFromPreCache(latest)
           }
