@@ -19,7 +19,7 @@ package org.apache.streampark.flink.packer.pipeline.impl
 
 import org.apache.streampark.common.conf.Workspace
 import org.apache.streampark.common.enums.DevelopmentMode
-import org.apache.streampark.common.fs.{FsOperator, HdfsOperator, LfsOperator}
+import org.apache.streampark.common.fs.{FsOperator, HdfsOperator}
 import org.apache.streampark.common.util.Utils
 import org.apache.streampark.flink.packer.maven.MavenTool
 import org.apache.streampark.flink.packer.pipeline._
@@ -43,34 +43,22 @@ class FlinkYarnApplicationBuildPipeline(request: FlinkYarnApplicationBuildReques
    */
   @throws[Throwable]
   override protected def buildProcess(): SimpleBuildResponse = {
-    execStep(1) {
-      request.developmentMode match {
-        case DevelopmentMode.FLINK_SQL =>
-          LfsOperator.mkCleanDirs(request.localWorkspace)
-          HdfsOperator.mkCleanDirs(request.yarnProvidedPath)
-        case _ =>
-      }
-      logInfo(s"recreate building workspace: ${request.yarnProvidedPath}")
-    }.getOrElse(throw getError.exception)
-
-    val mavenJars =
-      execStep(2) {
-        request.developmentMode match {
-          case DevelopmentMode.FLINK_SQL =>
-            val mavenArts = MavenTool.resolveArtifacts(request.dependencyInfo.mavenArts)
-            mavenArts.map(_.getAbsolutePath) ++ request.dependencyInfo.extJarLibs
-          case _ => Set[String]()
-        }
+    if (request.developmentMode == DevelopmentMode.FLINK_SQL) {
+      execStep(1) {
+        HdfsOperator.mkCleanDirs(request.yarnProvidedPath)
+        logInfo(s"recreate building workspace: ${request.yarnProvidedPath}")
       }.getOrElse(throw getError.exception)
 
-    execStep(3) {
-      mavenJars.foreach(
-        jar => {
-          uploadToHdfs(FsOperator.lfs, jar, request.localWorkspace)
-          uploadToHdfs(FsOperator.hdfs, jar, request.yarnProvidedPath)
-        })
-    }.getOrElse(throw getError.exception)
+      val mavenJars =
+        execStep(2) {
+          val mavenArts = MavenTool.resolveArtifacts(request.dependencyInfo.mavenArts)
+          mavenArts.map(_.getAbsolutePath) ++ request.dependencyInfo.extJarLibs
+        }.getOrElse(throw getError.exception)
 
+      execStep(3) {
+        mavenJars.foreach(jar => uploadToHdfs(FsOperator.hdfs, jar, request.yarnProvidedPath))
+      }.getOrElse(throw getError.exception)
+    }
     SimpleBuildResponse()
   }
 
@@ -82,29 +70,21 @@ class FlinkYarnApplicationBuildPipeline(request: FlinkYarnApplicationBuildReques
     }
     if (originFile.isFile) {
       // check file in upload dir
-      fsOperator match {
-        case FsOperator.lfs =>
-          fsOperator.copy(originFile.getAbsolutePath, target)
-        case FsOperator.hdfs =>
-          val uploadFile = s"${Workspace.remote.APP_UPLOADS}/${originFile.getName}"
-          if (fsOperator.exists(uploadFile)) {
-            Utils.using(new FileInputStream(originFile))(
-              inputStream => {
-                if (DigestUtils.md5Hex(inputStream) != fsOperator.fileMd5(uploadFile)) {
-                  fsOperator.upload(originFile.getAbsolutePath, uploadFile)
-                }
-              })
-          } else {
-            fsOperator.upload(originFile.getAbsolutePath, uploadFile)
-          }
-          // copy jar from upload dir to target dir
-          fsOperator.copy(uploadFile, target)
+      val uploadFile = s"${Workspace.remote.APP_UPLOADS}/${originFile.getName}"
+      if (fsOperator.exists(uploadFile)) {
+        Utils.using(new FileInputStream(originFile))(
+          inputStream => {
+            if (DigestUtils.md5Hex(inputStream) != fsOperator.fileMd5(uploadFile)) {
+              fsOperator.upload(originFile.getAbsolutePath, uploadFile)
+            }
+          })
+      } else {
+        fsOperator.upload(originFile.getAbsolutePath, uploadFile)
       }
+      // copy jar from upload dir to target dir
+      fsOperator.copy(uploadFile, target)
     } else {
-      fsOperator match {
-        case FsOperator.hdfs => fsOperator.upload(originFile.getAbsolutePath, target)
-        case _ =>
-      }
+      fsOperator.upload(originFile.getAbsolutePath, target)
     }
   }
 
